Crate finit

Crate finit 

A library for working with sets, their relationships and operations.

The main traits are:

  • Set - the most basic trait that all sets must implement to be able to use operations and comparisons, since most require them.

Operations

Comparisons

This library was originally designed to create a permission system, but it can be used for any kind of system that requires set-based data structures.

Modules

collections
This module contains various collection types that can be used with the traits defined in this crate, such as WildcardHashMap and WildcardBTreeMap.
comparisons
This module contains traits for comparing sets, such as checking if two sets are equal, if one set is a subset of another, etc.
operations
This module contains traits for performing operations on sets, such as Union, Intersection, Difference, DisjunctiveUnion, etc.

Macros

set_eq_partial_eq_impl
A helper macro to implement SetEq for types that also implement PartialEq, since in many cases they will be the same.

Traits

Set
The most basic trait that all sets often must implement to be able to use operations and comparisons, since most require them.